@@ -13,9 +13,13 @@ typedef Eo Efl_Network_Connector;
 
 
 #endif
+/** Efl network connector class
+ *
+ * @ingroup Efl_Network_Connector
+ */
 #define EFL_NETWORK_CONNECTOR_CLASS efl_network_connector_class_get()
 
-EAPI const Eo_Class *efl_network_connector_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *efl_network_connector_class_get(void);
 
 
 #endif
